Cluster Analysis
================

Display differentially expressed genes that characterize the cluster.

**Inputs**
- Data: Data set.
- Custom Gene Sets: Genes to compare.

**Outputs**
- Selected Data: Data selected in the widget.


**Cluster Analysis** widget displays differentially expressed genes that characterize the cluster, and corresponding gene terms that describe differentially expressed genes.

![](images/cluster_analysis/Cluster-Analysis-stamped.png)

1. Info
2. Cluster Indicator
3. Batch Indicator
4. Gene Scoring
5. Gene Sets
6. Custom Gene Sets
7. Filter Genes
8. Filter Gene Sets

Example
-------

TODO: Example
